pub fn do_something<T: Config>()Expand description
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::do_something.
pub fn do_something<T: Config>()This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::do_something.